/*
 * Copyright (C) 2010 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License
 * version 3.0 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3.0 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * Authored by Ken VanDine <ken.vandine@canonical.com>
 */

using Gwibber;
using Gtk;
using System;

public class GwibberPoster
{
	static void Main (string [] args)
	{
		Application.Init ();
		Gtk.Window window = new Gtk.Window ("Gwibber Poster (Mono)");
		Gwibber.GtkEntry entry = new Gwibber.GtkEntry ();
		window.Add (entry);
		window.Resize (400, 150);
		window.ShowAll ();
		window.DeleteEvent += new DeleteEventHandler (on_close);
		Application.Run ();
	}

	static void on_close (object o, DeleteEventArgs args)
	{
		Application.Quit ();
	}
}
